import * as React from 'react';
import {DependencyList, EffectCallback} from "react";

/**
 * Accepts a function that contains imperative, possibly effectful code.
 *
 * @param func Imperative function that can return a cleanup function
 * @param deps If present, effect will only activate if the values in the list change.
 *
 * @version 16.8.0
 * @see https://reactjs.org/docs/hooks-reference.html#useeffect
 */
export default function useAsyncEffect(func: EffectCallback, deps?: DependencyList): void {
  React.useEffect(() => {
    (async () => {
      await func();
    })();
  }, deps);
};